dyads.data<- read.csv(file="C:/./Example10.1Data.csv", header=TRUE, sep=",")

#creating long-form data set
library(reshape2)
data.depr<- melt(dyads.data[,c("family", "individual", "relation", "depression1","depression2",
"depression3")], id.vars=c("family","individual", "relation"), variable.name="depr.visits",
value.name="depression")
data.qol<- melt(dyads.data[,c("qol1","qol2", "qol3")], variable.name="qol.visits", 
value.name="qol")
longform.data<- cbind(data.depr, data.qol)

#creating numeric variable for time
visit<- ifelse(longform.data$depr.visits=="depression1", 1, ifelse(longform.data$depr.visits
=="depression2", 2, 3)) 

#fitting hierarchical model (fails to converge) 
library(lme4)
summary(glmer(depression ~ relation + qol + visit + (1 + visit|family)
+ (1 + visit|family:individual), data=longform.data, 
family=binomial(link="logit"))) 

#fitting simpler hierarchical model (converges)
summary(fitted.model<- glmer(depression ~ relation + qol + visit 
+ (1|family), data=longform.data, family=binomial(link="logit"))) 

#checking model fit
null.model<- glm(depression ~ relation + qol + visit,
data=longform.data, family=binomial(link=logit))
print(deviance<- -2*(logLik(null.model)-logLik(fitted.model)))
print(p.value<- pchisq(deviance, df=1, lower.tail=FALSE))

#using fitted model for prediction
print(predict(fitted.model, data.frame(family=25, individual=1, 
relation="M", qol=3.5, visit=3), allow.new.levels=TRUE, re.form=NA, type="response"))

