real.estate.data<- read.csv(file="C:/./Example2.1Data.csv", 
header=TRUE, sep=",")

#rescaling variables and specifying reference categories
price10K<- real.estate.data$price/10000
sqftK<- real.estate.data$sqft/1000
heating.rel<- relevel(real.estate.data$heating, ref="none")
AC.rel<- relevel(real.estate.data$AC, ref="no")
lotK<- real.estate.data$lot/1000

#plotting histogram with fitted normal density
install.packages("rcompanion")
library(rcompanion)
plotNormalHistogram(price10K)

#testing for normality of distribution
shapiro.test(price10K)

#finding optimal lambda for Box-Cox tranformation
library(MASS)
BoxCox.fit<- boxcox(price10K ~ beds + baths + sqftK + heating.rel
+ AC.rel + lotK, data=real.estate.data, lambda = seq(-3,3,1/4), interp=FALSE)
BoxCox.data<- data.frame(BoxCox.fit$x, BoxCox.fit$y)
ordered.data<- BoxCox.data[with(BoxCox.data, order(-BoxCox.fit.y)),]
ordered.data[1,]

#applying Box-Cox tranformation with lambda=-1
tr.price10K<- 1-(1/price10K)

#plotting histogram for tranformed response
plotNormalHistogram(tr.price10K)

#testing for normality of distribution
shapiro.test(tr.price10K)

#fitting general linear model to transformed response
summary(fitted.model<- glm(tr.price10K ~ beds + baths + sqftK + heating.rel
+ AC.rel + lotK, data=real.estate.data, family=gaussian(link=identity)))

#outputting estimated sigma
sigma(fitted.model)

#checking model fit
null.model<- glm(tr.price10K ~ 1, family=gaussian(link=identity))
print(deviance<- -2*(logLik(null.model)-logLik(fitted.model)))
print(p.value<- pchisq(deviance, df=7, lower.tail=FALSE))

#using fitted model for prediction
pred.tr.price10K<-predict(fitted.model, data.frame(beds=4, baths=2, sqftK=1.68,
heating.rel="central", AC.rel="no", lotK=5))
print(pred.price<- 10000/(1-pred.tr.price10K))