transport.data<- read.csv(file="C:/./Example7.2Data.csv", 
header=TRUE, sep=",")

library(gamlss)

#computing new variables and making them part of the original data set
transport.data$propbiked<- transport.data$nbiked/transport.data$ntrips
transport.data$faculty<- ifelse(transport.data$status=="faculty",1,0)
transport.data$staff<- ifelse(transport.data$status=="staff",1,0)
transport.data$male<- ifelse(transport.data$gender=="M",1,0)

#fitting zero-inflated beta regression model
summary(fitted.model<- gamlss(propbiked  ~ faculty + staff + parking, 
mu.link="logit", nu.formula= ~ male + distance, nu.link="logit", 
data=transport.data, family=BEZI))

#checking model fit
null.model<- gamlss(propbiked  ~ 1, mu.link="logit", nu.formula= ~ 1, 
nu.link="logit", data=transport.data, family=BEZI)
print(deviance<- -2*(logLik(null.model)-logLik(fitted.model)))
print(p.value<- pchisq(deviance, df=5, lower.tail=FALSE))

#using fitted model for prediction 
param.pred<- predictAll(fitted.model, newdata=data.frame(parking=6, 
distance=3, faculty=0, staff=0, male=0), type="response")
print((1-param.pred$nu)*param.pred$mu)

