cholesterol.data<- read.csv(file="C:/./Example8.1Data.csv", 
header=TRUE, sep=",")

#creating long-form data set
library(reshape2)
longform.data<- melt(cholesterol.data, id.vars=c("id", "gender", "age"), 
variable.name = "LDLmonth", value.name="LDL")

#sorting long-form data set by id
longform.data<- longform.data[order(longform.data$id),]

#creating numeric variable for time
month<- ifelse(longform.data$LDLmonth=="LDL0", 0, ifelse(longform.data$LDLmonth
=="LDL6", 6, ifelse(longform.data$LDLmonth=="LDL9",9,24)))

#specifying reference category
gender.rel<- relevel(longform.data$gender, ref="M")

library(geepack)
library(MuMIn)

#fitting GEE model with unstructured working correlation matrix
summary(un.fitted.model<- geeglm(LDL ~ gender.rel + age + month, 
data=longform.data, id=id, family=gaussian(link="identity"), 
corstr="unstructured"))
QIC(un.fitted.model)

#fitting GEE model with autoregressive working correlation matrix
summary(ar1.fitted.model<- geeglm(LDL ~ gender.rel + age + month, 
data=longform.data, id=id, family=gaussian(link="identity"), 
corstr="ar1"))
QIC(ar1.fitted.model)

#fitting GEE model with compound symmetric (exchangeable) 
#working correlation matrix
summary(cs.fitted.model<- geeglm(LDL ~ gender.rel + age + month, 
data=longform.data, id=id, family=gaussian(link="identity"), 
corstr="exchangeable"))
QIC(cs.fitted.model)

#fitting GEE model with independent working correlation matrix
summary(ind.fitted.model<- geeglm(LDL ~ gender.rel + age + month, 
data=longform.data, id=id, family=gaussian(link="identity"), 
corstr="independence"))
QIC(ind.fitted.model)

#using AR fitted model for prediction
print(predict(ar1.fitted.model, data.frame(gender.rel="F", 
age=48, month=3)))
