psoriasis.data<- read.csv(file="C:/./Example9.1Data.csv", 
header=TRUE, sep=",")

#creating long-form data set
library(reshape2)
longform.data<- melt(psoriasis.data, id.vars=c("patid", "group"), 
variable.name = "visits", value.name="npatches")

#creating numeric variable for time
weeks<- ifelse(longform.data$visits=="day1", 0.14, ifelse(longform.data$visits
=="week1", 1, ifelse(longform.data$visits=="week2", 2,ifelse(longform.data$visits=="week5", 
5, 13))))

#specifying reference category
group.rel<- relevel(longform.data$group, ref="Tx")

#fitting random slope and intercept Poisson model
library(lme4)

summary(glmer(npatches ~ group.rel + weeks 
+ (1 + weeks|patid), data=longform.data, 
family=poisson(link="log")))

#fitting random intercept-only Poisson model
summary(fitted.model<- glmer(npatches ~ group.rel + weeks + (1|patid), 
data=longform.data, family=poisson(link="log")))

#computing AICC
n<- 50
p<- 4 
print(AICC<- -2*logLik(fitted.model)+2*p*n/(n-p-1))

#checking model fit
null.model<- glm(npatches ~ group.rel + weeks,
data=longform.data, family=poisson(link=log))
print(deviance<- -2*(logLik(null.model)-logLik(fitted.model)))
print(p.value<- pchisq(deviance, df=1, lower.tail=FALSE))

#using fitted model for prediction
print(predict(fitted.model, data.frame(patid=11, group.rel="Tx", 
weeks=5), re.form=NA, type="response"))


